#  coding: utf-8
#  ----------------------------------------------------------------------------
#  <copyright company="Aspose" file="VectorRasterizationOptionsDTO.py">
#    Copyright (c) 2018-2019 Aspose Pty Ltd. All rights reserved.
#  </copyright>
#  <summary>
#    Permission is hereby granted, free of charge, to any person obtaining a
#   copy  of this software and associated documentation files (the "Software"),
#   to deal  in the Software without restriction, including without limitation
#   the rights  to use, copy, modify, merge, publish, distribute, sublicense,
#   and/or sell  copies of the Software, and to permit persons to whom the
#   Software is  furnished to do so, subject to the following conditions:
#
#   The above copyright notice and this permission notice shall be included in
#   all  copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#   FROM,  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#   DEALINGS IN THE SOFTWARE.
#  </summary>
#  ----------------------------------------------------------------------------

import pprint
import re
import six

from asposecadcloud.models.color import Color
from asposecadcloud.models.graphics_options import GraphicsOptions


class VectorRasterizationOptionsDTO(object):
    """Base raster export options class
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'border_x': 'float',
        'border_y': 'float',
        'page_height': 'float',
        'page_width': 'float',
        'background_color': 'Color',
        'draw_color': 'Color',
        'unit_type': 'str',
        'content_as_bitmap': 'bool',
        'graphics_options': 'GraphicsOptions'
    }

    attribute_map = {
        'border_x': 'BorderX',
        'border_y': 'BorderY',
        'page_height': 'PageHeight',
        'page_width': 'PageWidth',
        'background_color': 'BackgroundColor',
        'draw_color': 'DrawColor',
        'unit_type': 'UnitType',
        'content_as_bitmap': 'ContentAsBitmap',
        'graphics_options': 'GraphicsOptions'
    }

    discriminator_value_class_map = {
        'CadRasterizationOptionsDTO': 'CadRasterizationOptionsDTO'
    }

    def __init__(self, border_x=None, border_y=None, page_height=None, page_width=None, background_color=None, draw_color=None, unit_type=None, content_as_bitmap=None, graphics_options=None):
        """VectorRasterizationOptionsDTO - a model defined in Swagger"""
        super(VectorRasterizationOptionsDTO, self).__init__()

        self._border_x = None
        self._border_y = None
        self._page_height = None
        self._page_width = None
        self._background_color = None
        self._draw_color = None
        self._unit_type = None
        self._content_as_bitmap = None
        self._graphics_options = None

        if border_x is not None:
            self.border_x = border_x
        if border_y is not None:
            self.border_y = border_y
        if page_height is not None:
            self.page_height = page_height
        if page_width is not None:
            self.page_width = page_width
        if background_color is not None:
            self.background_color = background_color
        if draw_color is not None:
            self.draw_color = draw_color
        if unit_type is not None:
            self.unit_type = unit_type
        if content_as_bitmap is not None:
            self.content_as_bitmap = content_as_bitmap
        if graphics_options is not None:
            self.graphics_options = graphics_options

    @property
    def border_x(self):
        """Gets the border_x of this VectorRasterizationOptionsDTO.

        Gets or sets the border X.

        :return: The border_x of this VectorRasterizationOptionsDTO.
        :rtype: float
        """
        return self._border_x

    @border_x.setter
    def border_x(self, border_x):
        """Sets the border_x of this VectorRasterizationOptionsDTO.

        Gets or sets the border X.

        :param border_x: The border_x of this VectorRasterizationOptionsDTO.
        :type: float
        """
        if border_x is None:
            raise ValueError("Invalid value for `border_x`, must not be `None`")
        self._border_x = border_x

    @property
    def border_y(self):
        """Gets the border_y of this VectorRasterizationOptionsDTO.

        Gets or sets the border Y.

        :return: The border_y of this VectorRasterizationOptionsDTO.
        :rtype: float
        """
        return self._border_y

    @border_y.setter
    def border_y(self, border_y):
        """Sets the border_y of this VectorRasterizationOptionsDTO.

        Gets or sets the border Y.

        :param border_y: The border_y of this VectorRasterizationOptionsDTO.
        :type: float
        """
        if border_y is None:
            raise ValueError("Invalid value for `border_y`, must not be `None`")
        self._border_y = border_y

    @property
    def page_height(self):
        """Gets the page_height of this VectorRasterizationOptionsDTO.

        Gets or sets the page height.

        :return: The page_height of this VectorRasterizationOptionsDTO.
        :rtype: float
        """
        return self._page_height

    @page_height.setter
    def page_height(self, page_height):
        """Sets the page_height of this VectorRasterizationOptionsDTO.

        Gets or sets the page height.

        :param page_height: The page_height of this VectorRasterizationOptionsDTO.
        :type: float
        """
        if page_height is None:
            raise ValueError("Invalid value for `page_height`, must not be `None`")
        self._page_height = page_height

    @property
    def page_width(self):
        """Gets the page_width of this VectorRasterizationOptionsDTO.

        Gets or sets the page width.

        :return: The page_width of this VectorRasterizationOptionsDTO.
        :rtype: float
        """
        return self._page_width

    @page_width.setter
    def page_width(self, page_width):
        """Sets the page_width of this VectorRasterizationOptionsDTO.

        Gets or sets the page width.

        :param page_width: The page_width of this VectorRasterizationOptionsDTO.
        :type: float
        """
        if page_width is None:
            raise ValueError("Invalid value for `page_width`, must not be `None`")
        self._page_width = page_width

    @property
    def background_color(self):
        """Gets the background_color of this VectorRasterizationOptionsDTO.

        Gets or sets a background color.

        :return: The background_color of this VectorRasterizationOptionsDTO.
        :rtype: Color
        """
        return self._background_color

    @background_color.setter
    def background_color(self, background_color):
        """Sets the background_color of this VectorRasterizationOptionsDTO.

        Gets or sets a background color.

        :param background_color: The background_color of this VectorRasterizationOptionsDTO.
        :type: Color
        """
        if background_color is None:
            raise ValueError("Invalid value for `background_color`, must not be `None`")
        self._background_color = background_color

    @property
    def draw_color(self):
        """Gets the draw_color of this VectorRasterizationOptionsDTO.

        Gets or sets a foreground color.

        :return: The draw_color of this VectorRasterizationOptionsDTO.
        :rtype: Color
        """
        return self._draw_color

    @draw_color.setter
    def draw_color(self, draw_color):
        """Sets the draw_color of this VectorRasterizationOptionsDTO.

        Gets or sets a foreground color.

        :param draw_color: The draw_color of this VectorRasterizationOptionsDTO.
        :type: Color
        """
        if draw_color is None:
            raise ValueError("Invalid value for `draw_color`, must not be `None`")
        self._draw_color = draw_color

    @property
    def unit_type(self):
        """Gets the unit_type of this VectorRasterizationOptionsDTO.


        :return: The unit_type of this VectorRasterizationOptionsDTO.
        :rtype: str
        """
        return self._unit_type

    @unit_type.setter
    def unit_type(self, unit_type):
        """Sets the unit_type of this VectorRasterizationOptionsDTO.


        :param unit_type: The unit_type of this VectorRasterizationOptionsDTO.
        :type: str
        """
        if unit_type is None:
            raise ValueError("Invalid value for `unit_type`, must not be `None`")
        allowed_values = ["Kilometer", "Meter", "Centimenter", "Millimeter", "Micrometer", "Nanometer", "Angstrom", "Decimeter", "Decameter", "Hectometer", "Gigameter", "AstronomicalUnit", "LightYear", "Parsec", "Mile", "Yard", "Foot", "Inch", "Mil", "MicroInch", "Custom", "Unitless"]
        if not unit_type.isdigit():
            if unit_type not in allowed_values:
                raise ValueError(
                    "Invalid value for `unit_type` ({0}), must be one of {1}"
                    .format(unit_type, allowed_values))
            self._unit_type = unit_type
        else:
            self._unit_type = allowed_values[int(unit_type) if six.PY3 else long(unit_type)]

    @property
    def content_as_bitmap(self):
        """Gets the content_as_bitmap of this VectorRasterizationOptionsDTO.

        Gets or sets a value indicating whether content of a drawing is represented as image inside Pdf. Applicable only for CAD to Pdf export. Default is false.

        :return: The content_as_bitmap of this VectorRasterizationOptionsDTO.
        :rtype: bool
        """
        return self._content_as_bitmap

    @content_as_bitmap.setter
    def content_as_bitmap(self, content_as_bitmap):
        """Sets the content_as_bitmap of this VectorRasterizationOptionsDTO.

        Gets or sets a value indicating whether content of a drawing is represented as image inside Pdf. Applicable only for CAD to Pdf export. Default is false.

        :param content_as_bitmap: The content_as_bitmap of this VectorRasterizationOptionsDTO.
        :type: bool
        """
        if content_as_bitmap is None:
            raise ValueError("Invalid value for `content_as_bitmap`, must not be `None`")
        self._content_as_bitmap = content_as_bitmap

    @property
    def graphics_options(self):
        """Gets the graphics_options of this VectorRasterizationOptionsDTO.

        Gets or sets options to render bitmap inside pdf (if ContentAsBitmap is set to true).

        :return: The graphics_options of this VectorRasterizationOptionsDTO.
        :rtype: GraphicsOptions
        """
        return self._graphics_options

    @graphics_options.setter
    def graphics_options(self, graphics_options):
        """Sets the graphics_options of this VectorRasterizationOptionsDTO.

        Gets or sets options to render bitmap inside pdf (if ContentAsBitmap is set to true).

        :param graphics_options: The graphics_options of this VectorRasterizationOptionsDTO.
        :type: GraphicsOptions
        """
        self._graphics_options = graphics_options

    def get_real_child_model(self, data):
        """Returns the real base class specified by the discriminator"""
        discriminator_value = data.get(self.discriminator)
        return self.discriminator_value_class_map.get(discriminator_value.lower()) if discriminator_value else None

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VectorRasterizationOptionsDTO):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



#  coding: utf-8
#  ----------------------------------------------------------------------------
#  <copyright company="Aspose" file="PsdOptionsDTO.py">
#    Copyright (c) 2018-2019 Aspose Pty Ltd. All rights reserved.
#  </copyright>
#  <summary>
#    Permission is hereby granted, free of charge, to any person obtaining a
#   copy  of this software and associated documentation files (the "Software"),
#   to deal  in the Software without restriction, including without limitation
#   the rights  to use, copy, modify, merge, publish, distribute, sublicense,
#   and/or sell  copies of the Software, and to permit persons to whom the
#   Software is  furnished to do so, subject to the following conditions:
#
#   The above copyright notice and this permission notice shall be included in
#   all  copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#   FROM,  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#   DEALINGS IN THE SOFTWARE.
#  </summary>
#  ----------------------------------------------------------------------------

import pprint
import re
import six

from asposecadcloud.models.cad_rasterization_options_dto import CadRasterizationOptionsDTO
from asposecadcloud.models.drawing_options_base_dto import DrawingOptionsBaseDTO
from asposecadcloud.models.resolution_setting import ResolutionSetting


class PsdOptionsDTO(DrawingOptionsBaseDTO):
    """Export options for PSD format
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'version': 'int',
        'compression_method': 'object',
        'color_mode': 'object',
        'channel_bits_count': 'int',
        'channels_count': 'int'
    }

    attribute_map = {
        'version': 'Version',
        'compression_method': 'CompressionMethod',
        'color_mode': 'ColorMode',
        'channel_bits_count': 'ChannelBitsCount',
        'channels_count': 'ChannelsCount'
    }

    def __init__(self, version=None, compression_method=None, color_mode=None, channel_bits_count=None, channels_count=None):
        """PsdOptionsDTO - a model defined in Swagger"""
        super(PsdOptionsDTO, self).__init__()

        self._version = None
        self._compression_method = None
        self._color_mode = None
        self._channel_bits_count = None
        self._channels_count = None

        if version is not None:
            self.version = version
        if compression_method is not None:
            self.compression_method = compression_method
        if color_mode is not None:
            self.color_mode = color_mode
        if channel_bits_count is not None:
            self.channel_bits_count = channel_bits_count
        if channels_count is not None:
            self.channels_count = channels_count

    @property
    def version(self):
        """Gets the version of this PsdOptionsDTO.

        PSD format version

        :return: The version of this PsdOptionsDTO.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this PsdOptionsDTO.

        PSD format version

        :param version: The version of this PsdOptionsDTO.
        :type: int
        """
        if version is None:
            raise ValueError("Invalid value for `version`, must not be `None`")
        self._version = version

    @property
    def compression_method(self):
        """Gets the compression_method of this PsdOptionsDTO.

        Compression method

        :return: The compression_method of this PsdOptionsDTO.
        :rtype: object
        """
        return self._compression_method

    @compression_method.setter
    def compression_method(self, compression_method):
        """Sets the compression_method of this PsdOptionsDTO.

        Compression method

        :param compression_method: The compression_method of this PsdOptionsDTO.
        :type: object
        """
        if compression_method is None:
            raise ValueError("Invalid value for `compression_method`, must not be `None`")
        self._compression_method = compression_method

    @property
    def color_mode(self):
        """Gets the color_mode of this PsdOptionsDTO.

        Color mode

        :return: The color_mode of this PsdOptionsDTO.
        :rtype: object
        """
        return self._color_mode

    @color_mode.setter
    def color_mode(self, color_mode):
        """Sets the color_mode of this PsdOptionsDTO.

        Color mode

        :param color_mode: The color_mode of this PsdOptionsDTO.
        :type: object
        """
        if color_mode is None:
            raise ValueError("Invalid value for `color_mode`, must not be `None`")
        self._color_mode = color_mode

    @property
    def channel_bits_count(self):
        """Gets the channel_bits_count of this PsdOptionsDTO.

        Bits count per channel

        :return: The channel_bits_count of this PsdOptionsDTO.
        :rtype: int
        """
        return self._channel_bits_count

    @channel_bits_count.setter
    def channel_bits_count(self, channel_bits_count):
        """Sets the channel_bits_count of this PsdOptionsDTO.

        Bits count per channel

        :param channel_bits_count: The channel_bits_count of this PsdOptionsDTO.
        :type: int
        """
        if channel_bits_count is None:
            raise ValueError("Invalid value for `channel_bits_count`, must not be `None`")
        self._channel_bits_count = channel_bits_count

    @property
    def channels_count(self):
        """Gets the channels_count of this PsdOptionsDTO.

        Channels count

        :return: The channels_count of this PsdOptionsDTO.
        :rtype: int
        """
        return self._channels_count

    @channels_count.setter
    def channels_count(self, channels_count):
        """Sets the channels_count of this PsdOptionsDTO.

        Channels count

        :param channels_count: The channels_count of this PsdOptionsDTO.
        :type: int
        """
        if channels_count is None:
            raise ValueError("Invalid value for `channels_count`, must not be `None`")
        self._channels_count = channels_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PsdOptionsDTO):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



-8
#  ----------------------------------------------------------------------------
#  <copyright company="Aspose" file="GetDrawingSaveAsRequest.py">
#    Copyright (c) 2018-2019 Aspose Pty Ltd. All rights reserved.
#  </copyright>
#  <summary>
#    Permission is hereby granted, free of charge, to any person obtaining a
#   copy  of this software and associated documentation files (the "Software"),
#   to deal  in the Software without restriction, including without limitation
#   the rights  to use, copy, modify, merge, publish, distribute, sublicense,
#   and/or sell  copies of the Software, and to permit persons to whom the
#   Software is  furnished to do so, subject to the following conditions:
#
#   The above copyright notice and this permission notice shall be included in
#   all  copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#   FROM,  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#   DEALINGS IN THE SOFTWARE.
#  </summary>
#  ----------------------------------------------------------------------------

from asposecadcloud.models.requests.cad_request import CadRequest
from asposecadcloud.models.requests.http_request import HttpRequest


class GetDrawingSaveAsRequest(CadRequest):
    """
    Request model for get_drawing_save_as operation.
    Initializes a new instance.

    :param name Filename of an input drawing on a storage.
    :param output_format Resulting file format.
    :param folder Folder with a drawing to process.
    :param out_path Path to updated file (if this is empty, response contains streamed file).
    :param storage Your Aspose Cloud Storage name.
    """

    def __init__(self, name, output_format, folder=None, out_path=None, storage=None):
        CadRequest.__init__(self)
        self.name = name
        self.output_format = output_format
        self.folder = folder
        self.out_path = out_path
        self.storage = storage

    def to_http_info(self, config):
        """
        Prepares initial info for HTTP request

        :param config: CAD API configuration
        :type: asposecadcloud.Configuration
        :return: http_request configured http request
        :rtype: Configuration.models.requests.HttpRequest
        """
        # verify the required parameter 'name' is set
        if self.name is None:
            raise ValueError("Missing the required parameter `name` when calling `get_drawing_save_as`")
        # verify the required parameter 'output_format' is set
        if self.output_format is None:
            raise ValueError("Missing the required parameter `output_format` when calling `get_drawing_save_as`")

        collection_formats = {}
        path = '/cad/{name}/saveAs/{outputFormat}'
        path_params = {}
        if self.name is not None:
            path_params[self._lowercase_first_letter('name')] = self.name
        if self.output_format is not None:
            path_params[self._lowercase_first_letter('outputFormat')] = self.output_format

        query_params = []
        if self._lowercase_first_letter('folder') in path:
            path = path.replace('{' + self._lowercase_first_letter('folder' + '}'), self.folder if self.folder is not None else '')
        else:
            if self.folder is not None:
                query_params.append((self._lowercase_first_letter('folder'), self.folder))
        if self._lowercase_first_letter('outPath') in path:
            path = path.replace('{' + self._lowercase_first_letter('outPath' + '}'), self.out_path if self.out_path is not None else '')
        else:
            if self.out_path is not None:
                query_params.append((self._lowercase_first_letter('outPath'), self.out_path))
        if self._lowercase_first_letter('storage') in path:
            path = path.replace('{' + self._lowercase_first_letter('storage' + '}'), self.storage if self.storage is not None else '')
        else:
            if self.storage is not None:
                query_params.append((self._lowercase_first_letter('storage'), self.storage))

        header_params = {}

        form_params = []
        local_var_files = []

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self._select_header_accept(
            ['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = 'multipart/form-data' if form_params or local_var_files else self._select_header_content_type(
            ['application/json'])

        # Authentication setting
        auth_settings = ['JWT']

        return HttpRequest(path, path_params, query_params, header_params, form_params, body_params, local_var_files,
                           collection_formats, auth_settings)
#  coding: utf


#  coding: utf-8
#  ----------------------------------------------------------------------------
#  <copyright company="Aspose" file="GifOptionsDTO.py">
#    Copyright (c) 2018-2019 Aspose Pty Ltd. All rights reserved.
#  </copyright>
#  <summary>
#    Permission is hereby granted, free of charge, to any person obtaining a
#   copy  of this software and associated documentation files (the "Software"),
#   to deal  in the Software without restriction, including without limitation
#   the rights  to use, copy, modify, merge, publish, distribute, sublicense,
#   and/or sell  copies of the Software, and to permit persons to whom the
#   Software is  furnished to do so, subject to the following conditions:
#
#   The above copyright notice and this permission notice shall be included in
#   all  copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#   FROM,  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#   DEALINGS IN THE SOFTWARE.
#  </summary>
#  ----------------------------------------------------------------------------

import pprint
import re
import six

from asposecadcloud.models.cad_rasterization_options_dto import CadRasterizationOptionsDTO
from asposecadcloud.models.drawing_options_base_dto import DrawingOptionsBaseDTO
from asposecadcloud.models.resolution_setting import ResolutionSetting


class GifOptionsDTO(DrawingOptionsBaseDTO):
    """Export options for GIF format
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'do_palette_correction': 'bool',
        'color_resolution': 'int',
        'is_palette_sorted': 'bool',
        'pixel_aspect_ratio': 'int',
        'background_color_index': 'int',
        'has_trailer': 'bool',
        'interlaced': 'bool'
    }

    attribute_map = {
        'do_palette_correction': 'DoPaletteCorrection',
        'color_resolution': 'ColorResolution',
        'is_palette_sorted': 'IsPaletteSorted',
        'pixel_aspect_ratio': 'PixelAspectRatio',
        'background_color_index': 'BackgroundColorIndex',
        'has_trailer': 'HasTrailer',
        'interlaced': 'Interlaced'
    }

    def __init__(self, do_palette_correction=None, color_resolution=None, is_palette_sorted=None, pixel_aspect_ratio=None, background_color_index=None, has_trailer=None, interlaced=None):
        """GifOptionsDTO - a model defined in Swagger"""
        super(GifOptionsDTO, self).__init__()

        self._do_palette_correction = None
        self._color_resolution = None
        self._is_palette_sorted = None
        self._pixel_aspect_ratio = None
        self._background_color_index = None
        self._has_trailer = None
        self._interlaced = None

        if do_palette_correction is not None:
            self.do_palette_correction = do_palette_correction
        if color_resolution is not None:
            self.color_resolution = color_resolution
        if is_palette_sorted is not None:
            self.is_palette_sorted = is_palette_sorted
        if pixel_aspect_ratio is not None:
            self.pixel_aspect_ratio = pixel_aspect_ratio
        if background_color_index is not None:
            self.background_color_index = background_color_index
        if has_trailer is not None:
            self.has_trailer = has_trailer
        if interlaced is not None:
            self.interlaced = interlaced

    @property
    def do_palette_correction(self):
        """Gets the do_palette_correction of this GifOptionsDTO.

        Determines whether to do auto-correction of a palette

        :return: The do_palette_correction of this GifOptionsDTO.
        :rtype: bool
        """
        return self._do_palette_correction

    @do_palette_correction.setter
    def do_palette_correction(self, do_palette_correction):
        """Sets the do_palette_correction of this GifOptionsDTO.

        Determines whether to do auto-correction of a palette

        :param do_palette_correction: The do_palette_correction of this GifOptionsDTO.
        :type: bool
        """
        if do_palette_correction is None:
            raise ValueError("Invalid value for `do_palette_correction`, must not be `None`")
        self._do_palette_correction = do_palette_correction

    @property
    def color_resolution(self):
        """Gets the color_resolution of this GifOptionsDTO.

        Color resolution

        :return: The color_resolution of this GifOptionsDTO.
        :rtype: int
        """
        return self._color_resolution

    @color_resolution.setter
    def color_resolution(self, color_resolution):
        """Sets the color_resolution of this GifOptionsDTO.

        Color resolution

        :param color_resolution: The color_resolution of this GifOptionsDTO.
        :type: int
        """
        if color_resolution is None:
            raise ValueError("Invalid value for `color_resolution`, must not be `None`")
        self._color_resolution = color_resolution

    @property
    def is_palette_sorted(self):
        """Gets the is_palette_sorted of this GifOptionsDTO.

        Determines whether a palette is sorted

        :return: The is_palette_sorted of this GifOptionsDTO.
        :rtype: bool
        """
        return self._is_palette_sorted

    @is_palette_sorted.setter
    def is_palette_sorted(self, is_palette_sorted):
        """Sets the is_palette_sorted of this GifOptionsDTO.

        Determines whether a palette is sorted

        :param is_palette_sorted: The is_palette_sorted of this GifOptionsDTO.
        :type: bool
        """
        if is_palette_sorted is None:
            raise ValueError("Invalid value for `is_palette_sorted`, must not be `None`")
        self._is_palette_sorted = is_palette_sorted

    @property
    def pixel_aspect_ratio(self):
        """Gets the pixel_aspect_ratio of this GifOptionsDTO.

        Pixel aspect ration

        :return: The pixel_aspect_ratio of this GifOptionsDTO.
        :rtype: int
        """
        return self._pixel_aspect_ratio

    @pixel_aspect_ratio.setter
    def pixel_aspect_ratio(self, pixel_aspect_ratio):
        """Sets the pixel_aspect_ratio of this GifOptionsDTO.

        Pixel aspect ration

        :param pixel_aspect_ratio: The pixel_aspect_ratio of this GifOptionsDTO.
        :type: int
        """
        if pixel_aspect_ratio is None:
            raise ValueError("Invalid value for `pixel_aspect_ratio`, must not be `None`")
        self._pixel_aspect_ratio = pixel_aspect_ratio

    @property
    def background_color_index(self):
        """Gets the background_color_index of this GifOptionsDTO.

        Background color index

        :return: The background_color_index of this GifOptionsDTO.
        :rtype: int
        """
        return self._background_color_index

    @background_color_index.setter
    def background_color_index(self, background_color_index):
        """Sets the background_color_index of this GifOptionsDTO.

        Background color index

        :param background_color_index: The background_color_index of this GifOptionsDTO.
        :type: int
        """
        if background_color_index is None:
            raise ValueError("Invalid value for `background_color_index`, must not be `None`")
        self._background_color_index = background_color_index

    @property
    def has_trailer(self):
        """Gets the has_trailer of this GifOptionsDTO.

        Determines whether image has to have a trailer

        :return: The has_trailer of this GifOptionsDTO.
        :rtype: bool
        """
        return self._has_trailer

    @has_trailer.setter
    def has_trailer(self, has_trailer):
        """Sets the has_trailer of this GifOptionsDTO.

        Determines whether image has to have a trailer

        :param has_trailer: The has_trailer of this GifOptionsDTO.
        :type: bool
        """
        if has_trailer is None:
            raise ValueError("Invalid value for `has_trailer`, must not be `None`")
        self._has_trailer = has_trailer

    @property
    def interlaced(self):
        """Gets the interlaced of this GifOptionsDTO.

        Determines whether an image has to be interlaced

        :return: The interlaced of this GifOptionsDTO.
        :rtype: bool
        """
        return self._interlaced

    @interlaced.setter
    def interlaced(self, interlaced):
        """Sets the interlaced of this GifOptionsDTO.

        Determines whether an image has to be interlaced

        :param interlaced: The interlaced of this GifOptionsDTO.
        :type: bool
        """
        if interlaced is None:
            raise ValueError("Invalid value for `interlaced`, must not be `None`")
        self._interlaced = interlaced

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GifOptionsDTO):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



#  coding: utf-8
#  ----------------------------------------------------------------------------
#  <copyright company="Aspose" file="CadRasterizationOptionsDTO.py">
#    Copyright (c) 2018-2019 Aspose Pty Ltd. All rights reserved.
#  </copyright>
#  <summary>
#    Permission is hereby granted, free of charge, to any person obtaining a
#   copy  of this software and associated documentation files (the "Software"),
#   to deal  in the Software without restriction, including without limitation
#   the rights  to use, copy, modify, merge, publish, distribute, sublicense,
#   and/or sell  copies of the Software, and to permit persons to whom the
#   Software is  furnished to do so, subject to the following conditions:
#
#   The above copyright notice and this permission notice shall be included in
#   all  copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#   FROM,  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#   DEALINGS IN THE SOFTWARE.
#  </summary>
#  ----------------------------------------------------------------------------

import pprint
import re
import six

from asposecadcloud.models.color import Color
from asposecadcloud.models.graphics_options import GraphicsOptions
from asposecadcloud.models.pen_options import PenOptions
from asposecadcloud.models.vector_rasterization_options_dto import VectorRasterizationOptionsDTO


class CadRasterizationOptionsDTO(VectorRasterizationOptionsDTO):
    """Raster export options
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'zoom': 'float',
        'pen_options': 'PenOptions',
        'automatic_layouts_scaling': 'bool',
        'layers': 'list[str]',
        'layouts': 'list[str]',
        'draw_type': 'object',
        'no_scaling': 'bool'
    }

    attribute_map = {
        'zoom': 'Zoom',
        'pen_options': 'PenOptions',
        'automatic_layouts_scaling': 'AutomaticLayoutsScaling',
        'layers': 'Layers',
        'layouts': 'Layouts',
        'draw_type': 'DrawType',
        'no_scaling': 'NoScaling'
    }

    def __init__(self, zoom=None, pen_options=None, automatic_layouts_scaling=None, layers=None, layouts=None, draw_type=None, no_scaling=None):
        """CadRasterizationOptionsDTO - a model defined in Swagger"""
        super(CadRasterizationOptionsDTO, self).__init__()

        self._zoom = None
        self._pen_options = None
        self._automatic_layouts_scaling = None
        self._layers = None
        self._layouts = None
        self._draw_type = None
        self._no_scaling = None

        if zoom is not None:
            self.zoom = zoom
        if pen_options is not None:
            self.pen_options = pen_options
        if automatic_layouts_scaling is not None:
            self.automatic_layouts_scaling = automatic_layouts_scaling
        if layers is not None:
            self.layers = layers
        if layouts is not None:
            self.layouts = layouts
        if draw_type is not None:
            self.draw_type = draw_type
        if no_scaling is not None:
            self.no_scaling = no_scaling

    @property
    def zoom(self):
        """Gets the zoom of this CadRasterizationOptionsDTO.

        Zoom factor

        :return: The zoom of this CadRasterizationOptionsDTO.
        :rtype: float
        """
        return self._zoom

    @zoom.setter
    def zoom(self, zoom):
        """Sets the zoom of this CadRasterizationOptionsDTO.

        Zoom factor

        :param zoom: The zoom of this CadRasterizationOptionsDTO.
        :type: float
        """
        if zoom is None:
            raise ValueError("Invalid value for `zoom`, must not be `None`")
        self._zoom = zoom

    @property
    def pen_options(self):
        """Gets the pen_options of this CadRasterizationOptionsDTO.

        Pen options

        :return: The pen_options of this CadRasterizationOptionsDTO.
        :rtype: PenOptions
        """
        return self._pen_options

    @pen_options.setter
    def pen_options(self, pen_options):
        """Sets the pen_options of this CadRasterizationOptionsDTO.

        Pen options

        :param pen_options: The pen_options of this CadRasterizationOptionsDTO.
        :type: PenOptions
        """
        self._pen_options = pen_options

    @property
    def automatic_layouts_scaling(self):
        """Gets the automatic_layouts_scaling of this CadRasterizationOptionsDTO.

        Determines whether layout has to be scaled automatically

        :return: The automatic_layouts_scaling of this CadRasterizationOptionsDTO.
        :rtype: bool
        """
        return self._automatic_layouts_scaling

    @automatic_layouts_scaling.setter
    def automatic_layouts_scaling(self, automatic_layouts_scaling):
        """Sets the automatic_layouts_scaling of this CadRasterizationOptionsDTO.

        Determines whether layout has to be scaled automatically

        :param automatic_layouts_scaling: The automatic_layouts_scaling of this CadRasterizationOptionsDTO.
        :type: bool
        """
        if automatic_layouts_scaling is None:
            raise ValueError("Invalid value for `automatic_layouts_scaling`, must not be `None`")
        self._automatic_layouts_scaling = automatic_layouts_scaling

    @property
    def layers(self):
        """Gets the layers of this CadRasterizationOptionsDTO.

        Layers to export

        :return: The layers of this CadRasterizationOptionsDTO.
        :rtype: list[str]
        """
        return self._layers

    @layers.setter
    def layers(self, layers):
        """Sets the layers of this CadRasterizationOptionsDTO.

        Layers to export

        :param layers: The layers of this CadRasterizationOptionsDTO.
        :type: list[str]
        """
        self._layers = layers

    @property
    def layouts(self):
        """Gets the layouts of this CadRasterizationOptionsDTO.

        Layouts to export

        :return: The layouts of this CadRasterizationOptionsDTO.
        :rtype: list[str]
        """
        return self._layouts

    @layouts.setter
    def layouts(self, layouts):
        """Sets the layouts of this CadRasterizationOptionsDTO.

        Layouts to export

        :param layouts: The layouts of this CadRasterizationOptionsDTO.
        :type: list[str]
        """
        self._layouts = layouts

    @property
    def draw_type(self):
        """Gets the draw_type of this CadRasterizationOptionsDTO.

        Drawing mode

        :return: The draw_type of this CadRasterizationOptionsDTO.
        :rtype: object
        """
        return self._draw_type

    @draw_type.setter
    def draw_type(self, draw_type):
        """Sets the draw_type of this CadRasterizationOptionsDTO.

        Drawing mode

        :param draw_type: The draw_type of this CadRasterizationOptionsDTO.
        :type: object
        """
        if draw_type is None:
            raise ValueError("Invalid value for `draw_type`, must not be `None`")
        self._draw_type = draw_type

    @property
    def no_scaling(self):
        """Gets the no_scaling of this CadRasterizationOptionsDTO.

        Determines whether scaling has to be turned off

        :return: The no_scaling of this CadRasterizationOptionsDTO.
        :rtype: bool
        """
        return self._no_scaling

    @no_scaling.setter
    def no_scaling(self, no_scaling):
        """Sets the no_scaling of this CadRasterizationOptionsDTO.

        Determines whether scaling has to be turned off

        :param no_scaling: The no_scaling of this CadRasterizationOptionsDTO.
        :type: bool
        """
        if no_scaling is None:
            raise ValueError("Invalid value for `no_scaling`, must not be `None`")
        self._no_scaling = no_scaling

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CadRasterizationOptionsDTO):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



#  coding: utf-8
#  ----------------------------------------------------------------------------
#  <copyright company="Aspose" file="DrawingOptionsBaseDTO.py">
#    Copyright (c) 2018-2019 Aspose Pty Ltd. All rights reserved.
#  </copyright>
#  <summary>
#    Permission is hereby granted, free of charge, to any person obtaining a
#   copy  of this software and associated documentation files (the "Software"),
#   to deal  in the Software without restriction, including without limitation
#   the rights  to use, copy, modify, merge, publish, distribute, sublicense,
#   and/or sell  copies of the Software, and to permit persons to whom the
#   Software is  furnished to do so, subject to the following conditions:
#
#   The above copyright notice and this permission notice shall be included in
#   all  copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#   FROM,  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#   DEALINGS IN THE SOFTWARE.
#  </summary>
#  ----------------------------------------------------------------------------

import pprint
import re
import six

from asposecadcloud.models.cad_rasterization_options_dto import CadRasterizationOptionsDTO
from asposecadcloud.models.resolution_setting import ResolutionSetting


class DrawingOptionsBaseDTO(object):
    """Image options base class
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'rotation': 'object',
        'layers': 'list[str]',
        'resolution_settings': 'ResolutionSetting',
        'vector_rasterization_options': 'CadRasterizationOptionsDTO'
    }

    attribute_map = {
        'rotation': 'Rotation',
        'layers': 'Layers',
        'resolution_settings': 'ResolutionSettings',
        'vector_rasterization_options': 'VectorRasterizationOptions'
    }

    discriminator_value_class_map = {
        'PngOptionsDTO': 'PngOptionsDTO',
        'JpegOptionsDTO': 'JpegOptionsDTO',
        'BmpOptionsDTO': 'BmpOptionsDTO',
        'SvgOptionsDTO': 'SvgOptionsDTO',
        'Jpeg2000OptionsDTO': 'Jpeg2000OptionsDTO',
        'PdfOptionsDTO': 'PdfOptionsDTO',
        'PsdOptionsDTO': 'PsdOptionsDTO',
        'GifOptionsDTO': 'GifOptionsDTO',
        'WmfOptionsDTO': 'WmfOptionsDTO',
        'TiffOptionsDTO': 'TiffOptionsDTO'
    }

    def __init__(self, rotation=None, layers=None, resolution_settings=None, vector_rasterization_options=None):
        """DrawingOptionsBaseDTO - a model defined in Swagger"""
        super(DrawingOptionsBaseDTO, self).__init__()

        self._rotation = None
        self._layers = None
        self._resolution_settings = None
        self._vector_rasterization_options = None

        if rotation is not None:
            self.rotation = rotation
        if layers is not None:
            self.layers = layers
        if resolution_settings is not None:
            self.resolution_settings = resolution_settings
        if vector_rasterization_options is not None:
            self.vector_rasterization_options = vector_rasterization_options

    @property
    def rotation(self):
        """Gets the rotation of this DrawingOptionsBaseDTO.

        Resulting rotation operation

        :return: The rotation of this DrawingOptionsBaseDTO.
        :rtype: object
        """
        return self._rotation

    @rotation.setter
    def rotation(self, rotation):
        """Sets the rotation of this DrawingOptionsBaseDTO.

        Resulting rotation operation

        :param rotation: The rotation of this DrawingOptionsBaseDTO.
        :type: object
        """
        if rotation is None:
            raise ValueError("Invalid value for `rotation`, must not be `None`")
        self._rotation = rotation

    @property
    def layers(self):
        """Gets the layers of this DrawingOptionsBaseDTO.

        Layers to export

        :return: The layers of this DrawingOptionsBaseDTO.
        :rtype: list[str]
        """
        return self._layers

    @layers.setter
    def layers(self, layers):
        """Sets the layers of this DrawingOptionsBaseDTO.

        Layers to export

        :param layers: The layers of this DrawingOptionsBaseDTO.
        :type: list[str]
        """
        self._layers = layers

    @property
    def resolution_settings(self):
        """Gets the resolution_settings of this DrawingOptionsBaseDTO.

        DPI resolution settings

        :return: The resolution_settings of this DrawingOptionsBaseDTO.
        :rtype: ResolutionSetting
        """
        return self._resolution_settings

    @resolution_settings.setter
    def resolution_settings(self, resolution_settings):
        """Sets the resolution_settings of this DrawingOptionsBaseDTO.

        DPI resolution settings

        :param resolution_settings: The resolution_settings of this DrawingOptionsBaseDTO.
        :type: ResolutionSetting
        """
        self._resolution_settings = resolution_settings

    @property
    def vector_rasterization_options(self):
        """Gets the vector_rasterization_options of this DrawingOptionsBaseDTO.

        Raster options

        :return: The vector_rasterization_options of this DrawingOptionsBaseDTO.
        :rtype: CadRasterizationOptionsDTO
        """
        return self._vector_rasterization_options

    @vector_rasterization_options.setter
    def vector_rasterization_options(self, vector_rasterization_options):
        """Sets the vector_rasterization_options of this DrawingOptionsBaseDTO.

        Raster options

        :param vector_rasterization_options: The vector_rasterization_options of this DrawingOptionsBaseDTO.
        :type: CadRasterizationOptionsDTO
        """
        self._vector_rasterization_options = vector_rasterization_options

    def get_real_child_model(self, data):
        """Returns the real base class specified by the discriminator"""
        discriminator_value = data.get(self.discriminator)
        return self.discriminator_value_class_map.get(discriminator_value.lower()) if discriminator_value else None

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DrawingOptionsBaseDTO):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



#  coding: utf-8
#  ----------------------------------------------------------------------------
#  <copyright company="Aspose" file="RdOptimizerSettings.py">
#    Copyright (c) 2018-2019 Aspose Pty Ltd. All rights reserved.
#  </copyright>
#  <summary>
#    Permission is hereby granted, free of charge, to any person obtaining a
#   copy  of this software and associated documentation files (the "Software"),
#   to deal  in the Software without restriction, including without limitation
#   the rights  to use, copy, modify, merge, publish, distribute, sublicense,
#   and/or sell  copies of the Software, and to permit persons to whom the
#   Software is  furnished to do so, subject to the following conditions:
#
#   The above copyright notice and this permission notice shall be included in
#   all  copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#   FROM,  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#   DEALINGS IN THE SOFTWARE.
#  </summary>
#  ----------------------------------------------------------------------------

import pprint
import re
import six


class RdOptimizerSettings(object):
    """RD optimizer settings class
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'bpp_scale': 'int',
        'bpp_max': 'float',
        'max_q': 'int',
        'min_q': 'int',
        'max_pixel_value': 'int',
        'psnr_max': 'int',
        'discretized_bpp_max': 'int'
    }

    attribute_map = {
        'bpp_scale': 'BppScale',
        'bpp_max': 'BppMax',
        'max_q': 'MaxQ',
        'min_q': 'MinQ',
        'max_pixel_value': 'MaxPixelValue',
        'psnr_max': 'PsnrMax',
        'discretized_bpp_max': 'DiscretizedBppMax'
    }

    def __init__(self, bpp_scale=None, bpp_max=None, max_q=None, min_q=None, max_pixel_value=None, psnr_max=None, discretized_bpp_max=None):
        """RdOptimizerSettings - a model defined in Swagger"""
        super(RdOptimizerSettings, self).__init__()

        self._bpp_scale = None
        self._bpp_max = None
        self._max_q = None
        self._min_q = None
        self._max_pixel_value = None
        self._psnr_max = None
        self._discretized_bpp_max = None

        if bpp_scale is not None:
            self.bpp_scale = bpp_scale
        if bpp_max is not None:
            self.bpp_max = bpp_max
        if max_q is not None:
            self.max_q = max_q
        if min_q is not None:
            self.min_q = min_q
        if max_pixel_value is not None:
            self.max_pixel_value = max_pixel_value
        if psnr_max is not None:
            self.psnr_max = psnr_max
        if discretized_bpp_max is not None:
            self.discretized_bpp_max = discretized_bpp_max

    @property
    def bpp_scale(self):
        """Gets the bpp_scale of this RdOptimizerSettings.

        Gets or sets the BPP (bits per pixel) scale factor.

        :return: The bpp_scale of this RdOptimizerSettings.
        :rtype: int
        """
        return self._bpp_scale

    @bpp_scale.setter
    def bpp_scale(self, bpp_scale):
        """Sets the bpp_scale of this RdOptimizerSettings.

        Gets or sets the BPP (bits per pixel) scale factor.

        :param bpp_scale: The bpp_scale of this RdOptimizerSettings.
        :type: int
        """
        if bpp_scale is None:
            raise ValueError("Invalid value for `bpp_scale`, must not be `None`")
        self._bpp_scale = bpp_scale

    @property
    def bpp_max(self):
        """Gets the bpp_max of this RdOptimizerSettings.

        Gets or sets the maximum R value for consideration in  in bits per pixel

        :return: The bpp_max of this RdOptimizerSettings.
        :rtype: float
        """
        return self._bpp_max

    @bpp_max.setter
    def bpp_max(self, bpp_max):
        """Sets the bpp_max of this RdOptimizerSettings.

        Gets or sets the maximum R value for consideration in  in bits per pixel

        :param bpp_max: The bpp_max of this RdOptimizerSettings.
        :type: float
        """
        if bpp_max is None:
            raise ValueError("Invalid value for `bpp_max`, must not be `None`")
        self._bpp_max = bpp_max

    @property
    def max_q(self):
        """Gets the max_q of this RdOptimizerSettings.

        Gets or sets the maximum quantization value.

        :return: The max_q of this RdOptimizerSettings.
        :rtype: int
        """
        return self._max_q

    @max_q.setter
    def max_q(self, max_q):
        """Sets the max_q of this RdOptimizerSettings.

        Gets or sets the maximum quantization value.

        :param max_q: The max_q of this RdOptimizerSettings.
        :type: int
        """
        if max_q is None:
            raise ValueError("Invalid value for `max_q`, must not be `None`")
        self._max_q = max_q

    @property
    def min_q(self):
        """Gets the min_q of this RdOptimizerSettings.

        Gets the minimum allowed quantization value.

        :return: The min_q of this RdOptimizerSettings.
        :rtype: int
        """
        return self._min_q

    @min_q.setter
    def min_q(self, min_q):
        """Sets the min_q of this RdOptimizerSettings.

        Gets the minimum allowed quantization value.

        :param min_q: The min_q of this RdOptimizerSettings.
        :type: int
        """
        if min_q is None:
            raise ValueError("Invalid value for `min_q`, must not be `None`")
        self._min_q = min_q

    @property
    def max_pixel_value(self):
        """Gets the max_pixel_value of this RdOptimizerSettings.

        Gets the maximum pixel value.

        :return: The max_pixel_value of this RdOptimizerSettings.
        :rtype: int
        """
        return self._max_pixel_value

    @max_pixel_value.setter
    def max_pixel_value(self, max_pixel_value):
        """Sets the max_pixel_value of this RdOptimizerSettings.

        Gets the maximum pixel value.

        :param max_pixel_value: The max_pixel_value of this RdOptimizerSettings.
        :type: int
        """
        if max_pixel_value is None:
            raise ValueError("Invalid value for `max_pixel_value`, must not be `None`")
        self._max_pixel_value = max_pixel_value

    @property
    def psnr_max(self):
        """Gets the psnr_max of this RdOptimizerSettings.

        Gets the PSNR maximum expected value.

        :return: The psnr_max of this RdOptimizerSettings.
        :rtype: int
        """
        return self._psnr_max

    @psnr_max.setter
    def psnr_max(self, psnr_max):
        """Sets the psnr_max of this RdOptimizerSettings.

        Gets the PSNR maximum expected value.

        :param psnr_max: The psnr_max of this RdOptimizerSettings.
        :type: int
        """
        if psnr_max is None:
            raise ValueError("Invalid value for `psnr_max`, must not be `None`")
        self._psnr_max = psnr_max

    @property
    def discretized_bpp_max(self):
        """Gets the discretized_bpp_max of this RdOptimizerSettings.

        Gets the maximum R value for consideration.

        :return: The discretized_bpp_max of this RdOptimizerSettings.
        :rtype: int
        """
        return self._discretized_bpp_max

    @discretized_bpp_max.setter
    def discretized_bpp_max(self, discretized_bpp_max):
        """Sets the discretized_bpp_max of this RdOptimizerSettings.

        Gets the maximum R value for consideration.

        :param discretized_bpp_max: The discretized_bpp_max of this RdOptimizerSettings.
        :type: int
        """
        if discretized_bpp_max is None:
            raise ValueError("Invalid value for `discretized_bpp_max`, must not be `None`")
        self._discretized_bpp_max = discretized_bpp_max

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RdOptimizerSettings):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



#  coding: utf-8
#  ----------------------------------------------------------------------------
#  <copyright company="Aspose" file="StlProperties.py">
#    Copyright (c) 2018-2019 Aspose Pty Ltd. All rights reserved.
#  </copyright>
#  <summary>
#    Permission is hereby granted, free of charge, to any person obtaining a
#   copy  of this software and associated documentation files (the "Software"),
#   to deal  in the Software without restriction, including without limitation
#   the rights  to use, copy, modify, merge, publish, distribute, sublicense,
#   and/or sell  copies of the Software, and to permit persons to whom the
#   Software is  furnished to do so, subject to the following conditions:
#
#   The above copyright notice and this permission notice shall be included in
#   all  copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#   FROM,  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#   DEALINGS IN THE SOFTWARE.
#  </summary>
#  ----------------------------------------------------------------------------

import pprint
import re
import six


class StlProperties(object):
    """Represents information about STL drawing.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
    }

    attribute_map = {
    }

    def __init__(self):
        """StlProperties - a model defined in Swagger"""
        super(StlProperties, self).__init__()

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StlProperties):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



#  coding: utf-8
#  ----------------------------------------------------------------------------
#  <copyright company="Aspose" file="PngOptionsDTO.py">
#    Copyright (c) 2018-2019 Aspose Pty Ltd. All rights reserved.
#  </copyright>
#  <summary>
#    Permission is hereby granted, free of charge, to any person obtaining a
#   copy  of this software and associated documentation files (the "Software"),
#   to deal  in the Software without restriction, including without limitation
#   the rights  to use, copy, modify, merge, publish, distribute, sublicense,
#   and/or sell  copies of the Software, and to permit persons to whom the
#   Software is  furnished to do so, subject to the following conditions:
#
#   The above copyright notice and this permission notice shall be included in
#   all  copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#   FROM,  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#   DEALINGS IN THE SOFTWARE.
#  </summary>
#  ----------------------------------------------------------------------------

import pprint
import re
import six

from asposecadcloud.models.cad_rasterization_options_dto import CadRasterizationOptionsDTO
from asposecadcloud.models.drawing_options_base_dto import DrawingOptionsBaseDTO
from asposecadcloud.models.resolution_setting import ResolutionSetting


class PngOptionsDTO(DrawingOptionsBaseDTO):
    """Export options for PNG format
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'color_type': 'object',
        'progressive': 'bool',
        'filter_type': 'object',
        'compression_level': 'int',
        'bit_depth': 'int'
    }

    attribute_map = {
        'color_type': 'ColorType',
        'progressive': 'Progressive',
        'filter_type': 'FilterType',
        'compression_level': 'CompressionLevel',
        'bit_depth': 'BitDepth'
    }

    def __init__(self, color_type=None, progressive=None, filter_type=None, compression_level=None, bit_depth=None):
        """PngOptionsDTO - a model defined in Swagger"""
        super(PngOptionsDTO, self).__init__()

        self._color_type = None
        self._progressive = None
        self._filter_type = None
        self._compression_level = None
        self._bit_depth = None

        if color_type is not None:
            self.color_type = color_type
        if progressive is not None:
            self.progressive = progressive
        if filter_type is not None:
            self.filter_type = filter_type
        if compression_level is not None:
            self.compression_level = compression_level
        if bit_depth is not None:
            self.bit_depth = bit_depth

    @property
    def color_type(self):
        """Gets the color_type of this PngOptionsDTO.

        Color type

        :return: The color_type of this PngOptionsDTO.
        :rtype: object
        """
        return self._color_type

    @color_type.setter
    def color_type(self, color_type):
        """Sets the color_type of this PngOptionsDTO.

        Color type

        :param color_type: The color_type of this PngOptionsDTO.
        :type: object
        """
        if color_type is None:
            raise ValueError("Invalid value for `color_type`, must not be `None`")
        self._color_type = color_type

    @property
    def progressive(self):
        """Gets the progressive of this PngOptionsDTO.

        Determines whether 'progressive' method is used

        :return: The progressive of this PngOptionsDTO.
        :rtype: bool
        """
        return self._progressive

    @progressive.setter
    def progressive(self, progressive):
        """Sets the progressive of this PngOptionsDTO.

        Determines whether 'progressive' method is used

        :param progressive: The progressive of this PngOptionsDTO.
        :type: bool
        """
        if progressive is None:
            raise ValueError("Invalid value for `progressive`, must not be `None`")
        self._progressive = progressive

    @property
    def filter_type(self):
        """Gets the filter_type of this PngOptionsDTO.

        Filter type

        :return: The filter_type of this PngOptionsDTO.
        :rtype: object
        """
        return self._filter_type

    @filter_type.setter
    def filter_type(self, filter_type):
        """Sets the filter_type of this PngOptionsDTO.

        Filter type

        :param filter_type: The filter_type of this PngOptionsDTO.
        :type: object
        """
        if filter_type is None:
            raise ValueError("Invalid value for `filter_type`, must not be `None`")
        self._filter_type = filter_type

    @property
    def compression_level(self):
        """Gets the compression_level of this PngOptionsDTO.

        Compression level

        :return: The compression_level of this PngOptionsDTO.
        :rtype: int
        """
        return self._compression_level

    @compression_level.setter
    def compression_level(self, compression_level):
        """Sets the compression_level of this PngOptionsDTO.

        Compression level

        :param compression_level: The compression_level of this PngOptionsDTO.
        :type: int
        """
        if compression_level is None:
            raise ValueError("Invalid value for `compression_level`, must not be `None`")
        self._compression_level = compression_level

    @property
    def bit_depth(self):
        """Gets the bit_depth of this PngOptionsDTO.

        Bits depth

        :return: The bit_depth of this PngOptionsDTO.
        :rtype: int
        """
        return self._bit_depth

    @bit_depth.setter
    def bit_depth(self, bit_depth):
        """Sets the bit_depth of this PngOptionsDTO.

        Bits depth

        :param bit_depth: The bit_depth of this PngOptionsDTO.
        :type: int
        """
        if bit_depth is None:
            raise ValueError("Invalid value for `bit_depth`, must not be `None`")
        self._bit_depth = bit_depth

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PngOptionsDTO):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



#  coding: utf-8
#  ----------------------------------------------------------------------------
#  <copyright company="Aspose" file="CadResponse.py">
#    Copyright (c) 2018-2019 Aspose Pty Ltd. All rights reserved.
#  </copyright>
#  <summary>
#    Permission is hereby granted, free of charge, to any person obtaining a
#   copy  of this software and associated documentation files (the "Software"),
#   to deal  in the Software without restriction, including without limitation
#   the rights  to use, copy, modify, merge, publish, distribute, sublicense,
#   and/or sell  copies of the Software, and to permit persons to whom the
#   Software is  furnished to do so, subject to the following conditions:
#
#   The above copyright notice and this permission notice shall be included in
#   all  copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#   FROM,  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#   DEALINGS IN THE SOFTWARE.
#  </summary>
#  ----------------------------------------------------------------------------

import pprint
import re
import six

from asposecadcloud.models.cff2_properties import Cff2Properties
from asposecadcloud.models.dgn_properties import DgnProperties
from asposecadcloud.models.dwf_properties import DwfProperties
from asposecadcloud.models.dwg_properties import DwgProperties
from asposecadcloud.models.dxf_properties import DxfProperties
from asposecadcloud.models.ifc_properties import IfcProperties
from asposecadcloud.models.igs_properties import IgsProperties
from asposecadcloud.models.stl_properties import StlProperties


class CadResponse(object):
    """Represents information about a drawing.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'height': 'int',
        'width': 'int',
        'dwg_properties': 'DwgProperties',
        'dxf_properties': 'DxfProperties',
        'dwt_properties': 'DwgProperties',
        'dgn_properties': 'DgnProperties',
        'ifc_properties': 'IfcProperties',
        'igs_properties': 'IgsProperties',
        'stl_properties': 'StlProperties',
        'dwf_properties': 'DwfProperties',
        'cff2_properties': 'Cff2Properties'
    }

    attribute_map = {
        'height': 'Height',
        'width': 'Width',
        'dwg_properties': 'DwgProperties',
        'dxf_properties': 'DxfProperties',
        'dwt_properties': 'DwtProperties',
        'dgn_properties': 'DgnProperties',
        'ifc_properties': 'IfcProperties',
        'igs_properties': 'IgsProperties',
        'stl_properties': 'StlProperties',
        'dwf_properties': 'DwfProperties',
        'cff2_properties': 'Cff2Properties'
    }

    def __init__(self, height=None, width=None, dwg_properties=None, dxf_properties=None, dwt_properties=None, dgn_properties=None, ifc_properties=None, igs_properties=None, stl_properties=None, dwf_properties=None, cff2_properties=None):
        """CadResponse - a model defined in Swagger"""
        super(CadResponse, self).__init__()

        self._height = None
        self._width = None
        self._dwg_properties = None
        self._dxf_properties = None
        self._dwt_properties = None
        self._dgn_properties = None
        self._ifc_properties = None
        self._igs_properties = None
        self._stl_properties = None
        self._dwf_properties = None
        self._cff2_properties = None

        if height is not None:
            self.height = height
        if width is not None:
            self.width = width
        if dwg_properties is not None:
            self.dwg_properties = dwg_properties
        if dxf_properties is not None:
            self.dxf_properties = dxf_properties
        if dwt_properties is not None:
            self.dwt_properties = dwt_properties
        if dgn_properties is not None:
            self.dgn_properties = dgn_properties
        if ifc_properties is not None:
            self.ifc_properties = ifc_properties
        if igs_properties is not None:
            self.igs_properties = igs_properties
        if stl_properties is not None:
            self.stl_properties = stl_properties
        if dwf_properties is not None:
            self.dwf_properties = dwf_properties
        if cff2_properties is not None:
            self.cff2_properties = cff2_properties

    @property
    def height(self):
        """Gets the height of this CadResponse.

        Gets or sets the height of a drawing.

        :return: The height of this CadResponse.
        :rtype: int
        """
        return self._height

    @height.setter
    def height(self, height):
        """Sets the height of this CadResponse.

        Gets or sets the height of a drawing.

        :param height: The height of this CadResponse.
        :type: int
        """
        if height is None:
            raise ValueError("Invalid value for `height`, must not be `None`")
        self._height = height

    @property
    def width(self):
        """Gets the width of this CadResponse.

        Gets or sets the width of a drawing.

        :return: The width of this CadResponse.
        :rtype: int
        """
        return self._width

    @width.setter
    def width(self, width):
        """Sets the width of this CadResponse.

        Gets or sets the width of a drawing.

        :param width: The width of this CadResponse.
        :type: int
        """
        if width is None:
            raise ValueError("Invalid value for `width`, must not be `None`")
        self._width = width

    @property
    def dwg_properties(self):
        """Gets the dwg_properties of this CadResponse.

        Gets or sets the DWG properties.

        :return: The dwg_properties of this CadResponse.
        :rtype: DwgProperties
        """
        return self._dwg_properties

    @dwg_properties.setter
    def dwg_properties(self, dwg_properties):
        """Sets the dwg_properties of this CadResponse.

        Gets or sets the DWG properties.

        :param dwg_properties: The dwg_properties of this CadResponse.
        :type: DwgProperties
        """
        self._dwg_properties = dwg_properties

    @property
    def dxf_properties(self):
        """Gets the dxf_properties of this CadResponse.

        Gets or sets the DXF properties.

        :return: The dxf_properties of this CadResponse.
        :rtype: DxfProperties
        """
        return self._dxf_properties

    @dxf_properties.setter
    def dxf_properties(self, dxf_properties):
        """Sets the dxf_properties of this CadResponse.

        Gets or sets the DXF properties.

        :param dxf_properties: The dxf_properties of this CadResponse.
        :type: DxfProperties
        """
        self._dxf_properties = dxf_properties

    @property
    def dwt_properties(self):
        """Gets the dwt_properties of this CadResponse.

        Gets or sets the DWT properties.

        :return: The dwt_properties of this CadResponse.
        :rtype: DwgProperties
        """
        return self._dwt_properties

    @dwt_properties.setter
    def dwt_properties(self, dwt_properties):
        """Sets the dwt_properties of this CadResponse.

        Gets or sets the DWT properties.

        :param dwt_properties: The dwt_properties of this CadResponse.
        :type: DwgProperties
        """
        self._dwt_properties = dwt_properties

    @property
    def dgn_properties(self):
        """Gets the dgn_properties of this CadResponse.

        Gets or sets the DGN properties.

        :return: The dgn_properties of this CadResponse.
        :rtype: DgnProperties
        """
        return self._dgn_properties

    @dgn_properties.setter
    def dgn_properties(self, dgn_properties):
        """Sets the dgn_properties of this CadResponse.

        Gets or sets the DGN properties.

        :param dgn_properties: The dgn_properties of this CadResponse.
        :type: DgnProperties
        """
        self._dgn_properties = dgn_properties

    @property
    def ifc_properties(self):
        """Gets the ifc_properties of this CadResponse.

        Gets or sets the IFC properties.

        :return: The ifc_properties of this CadResponse.
        :rtype: IfcProperties
        """
        return self._ifc_properties

    @ifc_properties.setter
    def ifc_properties(self, ifc_properties):
        """Sets the ifc_properties of this CadResponse.

        Gets or sets the IFC properties.

        :param ifc_properties: The ifc_properties of this CadResponse.
        :type: IfcProperties
        """
        self._ifc_properties = ifc_properties

    @property
    def igs_properties(self):
        """Gets the igs_properties of this CadResponse.

        Gets or sets the IGS properties.

        :return: The igs_properties of this CadResponse.
        :rtype: IgsProperties
        """
        return self._igs_properties

    @igs_properties.setter
    def igs_properties(self, igs_properties):
        """Sets the igs_properties of this CadResponse.

        Gets or sets the IGS properties.

        :param igs_properties: The igs_properties of this CadResponse.
        :type: IgsProperties
        """
        self._igs_properties = igs_properties

    @property
    def stl_properties(self):
        """Gets the stl_properties of this CadResponse.

        Gets or sets the STL properties.

        :return: The stl_properties of this CadResponse.
        :rtype: StlProperties
        """
        return self._stl_properties

    @stl_properties.setter
    def stl_properties(self, stl_properties):
        """Sets the stl_properties of this CadResponse.

        Gets or sets the STL properties.

        :param stl_properties: The stl_properties of this CadResponse.
        :type: StlProperties
        """
        self._stl_properties = stl_properties

    @property
    def dwf_properties(self):
        """Gets the dwf_properties of this CadResponse.

        Gets or sets the DWF properties.

        :return: The dwf_properties of this CadResponse.
        :rtype: DwfProperties
        """
        return self._dwf_properties

    @dwf_properties.setter
    def dwf_properties(self, dwf_properties):
        """Sets the dwf_properties of this CadResponse.

        Gets or sets the DWF properties.

        :param dwf_properties: The dwf_properties of this CadResponse.
        :type: DwfProperties
        """
        self._dwf_properties = dwf_properties

    @property
    def cff2_properties(self):
        """Gets the cff2_properties of this CadResponse.

        Gets or sets the CFF2 properties.

        :return: The cff2_properties of this CadResponse.
        :rtype: Cff2Properties
        """
        return self._cff2_properties

    @cff2_properties.setter
    def cff2_properties(self, cff2_properties):
        """Sets the cff2_properties of this CadResponse.

        Gets or sets the CFF2 properties.

        :param cff2_properties: The cff2_properties of this CadResponse.
        :type: Cff2Properties
        """
        self._cff2_properties = cff2_properties

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CadResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from asposecadcloud.models.requests.http_request import HttpRequest
from asposecadcloud.models.requests.cad_request import CadRequest
from asposecadcloud.models.requests.put_drawing_wmf_request import PutDrawingWmfRequest
from asposecadcloud.models.requests.put_drawing_tiff_request import PutDrawingTiffRequest
from asposecadcloud.models.requests.put_drawing_svg_request import PutDrawingSvgRequest
from asposecadcloud.models.requests.put_drawing_psd_request import PutDrawingPsdRequest
from asposecadcloud.models.requests.put_drawing_png_request import PutDrawingPngRequest
from asposecadcloud.models.requests.put_drawing_pdf_request import PutDrawingPdfRequest
from asposecadcloud.models.requests.put_drawing_jpeg2000_request import PutDrawingJpeg2000Request
from asposecadcloud.models.requests.put_drawing_jpeg_request import PutDrawingJpegRequest
from asposecadcloud.models.requests.put_drawing_gif_request import PutDrawingGifRequest
from asposecadcloud.models.requests.put_drawing_bmp_request import PutDrawingBmpRequest
from asposecadcloud.models.requests.post_drawing_wmf_request import PostDrawingWmfRequest
from asposecadcloud.models.requests.post_drawing_tiff_request import PostDrawingTiffRequest
from asposecadcloud.models.requests.post_drawing_svg_request import PostDrawingSvgRequest
from asposecadcloud.models.requests.post_drawing_save_as_request import PostDrawingSaveAsRequest
from asposecadcloud.models.requests.post_drawing_rotate_flip_request import PostDrawingRotateFlipRequest
from asposecadcloud.models.requests.post_drawing_resize_request import PostDrawingResizeRequest
from asposecadcloud.models.requests.post_drawing_psd_request import PostDrawingPsdRequest
from asposecadcloud.models.requests.post_drawing_properties_request import PostDrawingPropertiesRequest
from asposecadcloud.models.requests.post_drawing_png_request import PostDrawingPngRequest
from asposecadcloud.models.requests.post_drawing_pdf_request import PostDrawingPdfRequest
from asposecadcloud.models.requests.post_drawing_jpeg2000_request import PostDrawingJpeg2000Request
from asposecadcloud.models.requests.post_drawing_jpeg_request import PostDrawingJpegRequest
from asposecadcloud.models.requests.post_drawing_gif_request import PostDrawingGifRequest
from asposecadcloud.models.requests.post_drawing_bmp_request import PostDrawingBmpRequest
from asposecadcloud.models.requests.get_drawing_save_as_request import GetDrawingSaveAsRequest
from asposecadcloud.models.requests.get_drawing_rotate_flip_request import GetDrawingRotateFlipRequest
from asposecadcloud.models.requests.get_drawing_resize_request import GetDrawingResizeRequest
from asposecadcloud.models.requests.get_drawing_properties_request import GetDrawingPropertiesRequest



#  coding: utf-8
#  ----------------------------------------------------------------------------
#  <copyright company="Aspose" file="Color.py">
#    Copyright (c) 2018-2019 Aspose Pty Ltd. All rights reserved.
#  </copyright>
#  <summary>
#    Permission is hereby granted, free of charge, to any person obtaining a
#   copy  of this software and associated documentation files (the "Software"),
#   to deal  in the Software without restriction, including without limitation
#   the rights  to use, copy, modify, merge, publish, distribute, sublicense,
#   and/or sell  copies of the Software, and to permit persons to whom the
#   Software is  furnished to do so, subject to the following conditions:
#
#   The above copyright notice and this permission notice shall be included in
#   all  copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#   FROM,  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#   DEALINGS IN THE SOFTWARE.
#  </summary>
#  ----------------------------------------------------------------------------

import pprint
import re
import six


class Color(object):
    """The color of the pixel.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'r': 'int',
        'g': 'int',
        'b': 'int',
        'a': 'int',
        'is_known_color': 'bool',
        'is_empty': 'bool',
        'is_named_color': 'bool',
        'name': 'str'
    }

    attribute_map = {
        'r': 'R',
        'g': 'G',
        'b': 'B',
        'a': 'A',
        'is_known_color': 'IsKnownColor',
        'is_empty': 'IsEmpty',
        'is_named_color': 'IsNamedColor',
        'name': 'Name'
    }

    def __init__(self, r=None, g=None, b=None, a=None, is_known_color=None, is_empty=None, is_named_color=None, name=None):
        """Color - a model defined in Swagger"""
        super(Color, self).__init__()

        self._r = None
        self._g = None
        self._b = None
        self._a = None
        self._is_known_color = None
        self._is_empty = None
        self._is_named_color = None
        self._name = None

        if r is not None:
            self.r = r
        if g is not None:
            self.g = g
        if b is not None:
            self.b = b
        if a is not None:
            self.a = a
        if is_known_color is not None:
            self.is_known_color = is_known_color
        if is_empty is not None:
            self.is_empty = is_empty
        if is_named_color is not None:
            self.is_named_color = is_named_color
        if name is not None:
            self.name = name

    @property
    def r(self):
        """Gets the r of this Color.

        Gets the red component value of this Color structure.

        :return: The r of this Color.
        :rtype: int
        """
        return self._r

    @r.setter
    def r(self, r):
        """Sets the r of this Color.

        Gets the red component value of this Color structure.

        :param r: The r of this Color.
        :type: int
        """
        if r is None:
            raise ValueError("Invalid value for `r`, must not be `None`")
        self._r = r

    @property
    def g(self):
        """Gets the g of this Color.

        Gets the green component value of this Color structure.

        :return: The g of this Color.
        :rtype: int
        """
        return self._g

    @g.setter
    def g(self, g):
        """Sets the g of this Color.

        Gets the green component value of this Color structure.

        :param g: The g of this Color.
        :type: int
        """
        if g is None:
            raise ValueError("Invalid value for `g`, must not be `None`")
        self._g = g

    @property
    def b(self):
        """Gets the b of this Color.

        Gets the blue component value of this Color structure.

        :return: The b of this Color.
        :rtype: int
        """
        return self._b

    @b.setter
    def b(self, b):
        """Sets the b of this Color.

        Gets the blue component value of this Color structure.

        :param b: The b of this Color.
        :type: int
        """
        if b is None:
            raise ValueError("Invalid value for `b`, must not be `None`")
        self._b = b

    @property
    def a(self):
        """Gets the a of this Color.

        Gets the alpha component value of this Color structure.

        :return: The a of this Color.
        :rtype: int
        """
        return self._a

    @a.setter
    def a(self, a):
        """Sets the a of this Color.

        Gets the alpha component value of this Color structure.

        :param a: The a of this Color.
        :type: int
        """
        if a is None:
            raise ValueError("Invalid value for `a`, must not be `None`")
        self._a = a

    @property
    def is_known_color(self):
        """Gets the is_known_color of this Color.

        Gets a value indicating whether this Color structure is a predefined color. Predefined colors are represented by the elements of the KnownColor enumeration.

        :return: The is_known_color of this Color.
        :rtype: bool
        """
        return self._is_known_color

    @is_known_color.setter
    def is_known_color(self, is_known_color):
        """Sets the is_known_color of this Color.

        Gets a value indicating whether this Color structure is a predefined color. Predefined colors are represented by the elements of the KnownColor enumeration.

        :param is_known_color: The is_known_color of this Color.
        :type: bool
        """
        if is_known_color is None:
            raise ValueError("Invalid value for `is_known_color`, must not be `None`")
        self._is_known_color = is_known_color

    @property
    def is_empty(self):
        """Gets the is_empty of this Color.

        Gets a value indicating whether this Color structure is uninitialized.

        :return: The is_empty of this Color.
        :rtype: bool
        """
        return self._is_empty

    @is_empty.setter
    def is_empty(self, is_empty):
        """Sets the is_empty of this Color.

        Gets a value indicating whether this Color structure is uninitialized.

        :param is_empty: The is_empty of this Color.
        :type: bool
        """
        if is_empty is None:
            raise ValueError("Invalid value for `is_empty`, must not be `None`")
        self._is_empty = is_empty

    @property
    def is_named_color(self):
        """Gets the is_named_color of this Color.

        Gets a value indicating whether this Color structure is a named color or a member of the KnownColor enumeration.

        :return: The is_named_color of this Color.
        :rtype: bool
        """
        return self._is_named_color

    @is_named_color.setter
    def is_named_color(self, is_named_color):
        """Sets the is_named_color of this Color.

        Gets a value indicating whether this Color structure is a named color or a member of the KnownColor enumeration.

        :param is_named_color: The is_named_color of this Color.
        :type: bool
        """
        if is_named_color is None:
            raise ValueError("Invalid value for `is_named_color`, must not be `None`")
        self._is_named_color = is_named_color

    @property
    def name(self):
        """Gets the name of this Color.

        Gets the name of this Color.

        :return: The name of this Color.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Color.

        Gets the name of this Color.

        :param name: The name of this Color.
        :type: str
        """
        self._name = name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Color):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



#  coding: utf-8
#  ----------------------------------------------------------------------------
#  <copyright company="Aspose" file="cad_api.py">
#    Copyright (c) 2018-2019 Aspose Pty Ltd. All rights reserved.
#  </copyright>
#  <summary>
#    Permission is hereby granted, free of charge, to any person obtaining a
#   copy  of this software and associated documentation files (the "Software"),
#   to deal  in the Software without restriction, including without limitation
#   the rights  to use, copy, modify, merge, publish, distribute, sublicense,
#   and/or sell  copies of the Software, and to permit persons to whom the
#   Software is  furnished to do so, subject to the following conditions:
#
#   The above copyright notice and this permission notice shall be included in
#   all  copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#   FROM,  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#   DEALINGS IN THE SOFTWARE.
#  </summary>
#  ----------------------------------------------------------------------------

from __future__ import absolute_import

import six

from asposecadcloud.api_client import ApiClient
from asposecadcloud.configuration import Configuration
from asposecadcloud.rest import ApiException


class CadApi(object):
    """
    Aspose.CAD Cloud API

    """

    def __init__(self, app_key=None, app_sid=None, base_url=None,
                 api_version=None, debug=False, proxy=None):
        """
        Initializes a new instance of the CadApi class.

        :param app_key: The app key.
        :param app_sid: The app sid.
        :param base_url: The base URL.
        :param api_version: API version.
        :param debug: If debug mode is enabled. False by default.
		:param proxy: proxy url if needed.
        :param on_premise:
            True for on-premise solution with metered license usage.
            False for Aspose Cloud-hosted solution usage, default.
        """
        configuration = Configuration(app_key=app_key,
                                      app_sid=app_sid,
                                      base_url=base_url,
                                      api_version=api_version,
                                      debug=debug,
									  proxy=proxy)
        self.api_client = ApiClient(configuration)

    def get_drawing_properties(self, request):
        """Retrieves info about an existing drawing.             


        :param request GetDrawingPropertiesRequest object with parameters
        :return: CadResponse
        """
        HttpRequest = request.to_http_info(self.api_client.configuration)
        return self.__make_request(HttpRequest, 'GET', 'CadResponse')

    def get_drawing_properties_async(self, request):
        """Retrieves info about an existing drawing.             


        :param request GetDrawingPropertiesRequest object with parameters
        :return: CadResponse
        """
        HttpRequest = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(HttpRequest, 'GET', 'CadResponse')

    def get_drawing_resize(self, request):
        """Resize an existing drawing.


        :param request GetDrawingResizeRequest object with parameters
        :return: file
        """
        HttpRequest = request.to_http_info(self.api_client.configuration)
        return self.__make_request(HttpRequest, 'GET', 'file')

    def get_drawing_resize_async(self, request):
        """Resize an existing drawing.


        :param request GetDrawingResizeRequest object with parameters
        :return: file
        """
        HttpRequest = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(HttpRequest, 'GET', 'file')

    def get_drawing_rotate_flip(self, request):
        """Rotate/flip an existing drawing.


        :param request GetDrawingRotateFlipRequest object with parameters
        :return: file
        """
        HttpRequest = request.to_http_info(self.api_client.configuration)
        return self.__make_request(HttpRequest, 'GET', 'file')

    def get_drawing_rotate_flip_async(self, request):
        """Rotate/flip an existing drawing.


        :param request GetDrawingRotateFlipRequest object with parameters
        :return: file
        """
        HttpRequest = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(HttpRequest, 'GET', 'file')

    def get_drawing_save_as(self, request):
        """Export an existing drawing to another format.


        :param request GetDrawingSaveAsRequest object with parameters
        :return: file
        """
        HttpRequest = request.to_http_info(self.api_client.configuration)
        return self.__make_request(HttpRequest, 'GET', 'file')

    def get_drawing_save_as_async(self, request):
        """Export an existing drawing to another format.


        :param request GetDrawingSaveAsRequest object with parameters
        :return: file
        """
        HttpRequest = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(HttpRequest, 'GET', 'file')

    def post_drawing_bmp(self, request):
        """Export an existing drawing to BMP format with export settings specified.


        :param request PostDrawingBmpRequest object with parameters
        :return: file
        """
        HttpRequest = request.to_http_info(self.api_client.configuration)
        return self.__make_request(HttpRequest, 'POST', 'file')

    def post_drawing_bmp_async(self, request):
        """Export an existing drawing to BMP format with export settings specified.


        :param request PostDrawingBmpRequest object with parameters
        :return: file
        """
        HttpRequest = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(HttpRequest, 'POST', 'file')

    def post_drawing_gif(self, request):
        """Export an existing drawing into GIF format with export settings specified.


        :param request PostDrawingGifRequest object with parameters
        :return: file
        """
        HttpRequest = request.to_http_info(self.api_client.configuration)
        return self.__make_request(HttpRequest, 'POST', 'file')

    def post_drawing_gif_async(self, request):
        """Export an existing drawing into GIF format with export settings specified.


        :param request PostDrawingGifRequest object with parameters
        :return: file
        """
        HttpRequest = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(HttpRequest, 'POST', 'file')

    def post_drawing_jpeg(self, request):
        """Export an existing drawing into JPEG format with export settings specified.


        :param request PostDrawingJpegRequest object with parameters
        :return: file
        """
        HttpRequest = request.to_http_info(self.api_client.configuration)
        return self.__make_request(HttpRequest, 'POST', 'file')

    def post_drawing_jpeg_async(self, request):
        """Export an existing drawing into JPEG format with export settings specified.


        :param request PostDrawingJpegRequest object with parameters
        :return: file
        """
        HttpRequest = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(HttpRequest, 'POST', 'file')

    def post_drawing_jpeg2000(self, request):
        """Export an existing drawing into JPEG2000 format with export settings specified.


        :param request PostDrawingJpeg2000Request object with parameters
        :return: file
        """
        HttpRequest = request.to_http_info(self.api_client.configuration)
        return self.__make_request(HttpRequest, 'POST', 'file')

    def post_drawing_jpeg2000_async(self, request):
        """Export an existing drawing into JPEG2000 format with export settings specified.


        :param request PostDrawingJpeg2000Request object with parameters
        :return: file
        """
        HttpRequest = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(HttpRequest, 'POST', 'file')

    def post_drawing_pdf(self, request):
        """Export an existing drawing to PDF format with export settings specified.


        :param request PostDrawingPdfRequest object with parameters
        :return: file
        """
        HttpRequest = request.to_http_info(self.api_client.configuration)
        return self.__make_request(HttpRequest, 'POST', 'file')

    def post_drawing_pdf_async(self, request):
        """Export an existing drawing to PDF format with export settings specified.


        :param request PostDrawingPdfRequest object with parameters
        :return: file
        """
        HttpRequest = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(HttpRequest, 'POST', 'file')

    def post_drawing_png(self, request):
        """Export an existing drawing into PNG format with export settings specified.


        :param request PostDrawingPngRequest object with parameters
        :return: file
        """
        HttpRequest = request.to_http_info(self.api_client.configuration)
        return self.__make_request(HttpRequest, 'POST', 'file')

    def post_drawing_png_async(self, request):
        """Export an existing drawing into PNG format with export settings specified.


        :param request PostDrawingPngRequest object with parameters
        :return: file
        """
        HttpRequest = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(HttpRequest, 'POST', 'file')

    def post_drawing_properties(self, request):
        """Retrieves info about drawing which is passed as a zero-indexed multipart/form-data content or as raw body stream.


        :param request PostDrawingPropertiesRequest object with parameters
        :return: CadResponse
        """
        HttpRequest = request.to_http_info(self.api_client.configuration)
        return self.__make_request(HttpRequest, 'POST', 'CadResponse')

    def post_drawing_properties_async(self, request):
        """Retrieves info about drawing which is passed as a zero-indexed multipart/form-data content or as raw body stream.


        :param request PostDrawingPropertiesRequest object with parameters
        :return: CadResponse
        """
        HttpRequest = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(HttpRequest, 'POST', 'CadResponse')

    def post_drawing_psd(self, request):
        """Export an existing drawing into PSD format with export settings specified.


        :param request PostDrawingPsdRequest object with parameters
        :return: file
        """
        HttpRequest = request.to_http_info(self.api_client.configuration)
        return self.__make_request(HttpRequest, 'POST', 'file')

    def post_drawing_psd_async(self, request):
        """Export an existing drawing into PSD format with export settings specified.


        :param request PostDrawingPsdRequest object with parameters
        :return: file
        """
        HttpRequest = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(HttpRequest, 'POST', 'file')

    def post_drawing_resize(self, request):
        """Resize a drawing. Drawing data is passed as a zero-indexed multipart/form-data content or as raw body stream.


        :param request PostDrawingResizeRequest object with parameters
        :return: file
        """
        HttpRequest = request.to_http_info(self.api_client.configuration)
        return self.__make_request(HttpRequest, 'POST', 'file')

    def post_drawing_resize_async(self, request):
        """Resize a drawing. Drawing data is passed as a zero-indexed multipart/form-data content or as raw body stream.


        :param request PostDrawingResizeRequest object with parameters
        :return: file
        """
        HttpRequest = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(HttpRequest, 'POST', 'file')

    def post_drawing_rotate_flip(self, request):
        """Rotate/flip a drawing. Drawing data is passed as a zero-indexed multipart/form-data content or as raw body stream.


        :param request PostDrawingRotateFlipRequest object with parameters
        :return: file
        """
        HttpRequest = request.to_http_info(self.api_client.configuration)
        return self.__make_request(HttpRequest, 'POST', 'file')

    def post_drawing_rotate_flip_async(self, request):
        """Rotate/flip a drawing. Drawing data is passed as a zero-indexed multipart/form-data content or as raw body stream.


        :param request PostDrawingRotateFlipRequest object with parameters
        :return: file
        """
        HttpRequest = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(HttpRequest, 'POST', 'file')

    def post_drawing_save_as(self, request):
        """Export existing drawing to another format. Drawing data is passed as zero-indexed multipart/form-data content or as raw body stream.             


        :param request PostDrawingSaveAsRequest object with parameters
        :return: file
        """
        HttpRequest = request.to_http_info(self.api_client.configuration)
        return self.__make_request(HttpRequest, 'POST', 'file')

    def post_drawing_save_as_async(self, request):
        """Export existing drawing to another format. Drawing data is passed as zero-indexed multipart/form-data content or as raw body stream.             


        :param request PostDrawingSaveAsRequest object with parameters
        :return: file
        """
        HttpRequest = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(HttpRequest, 'POST', 'file')

    def post_drawing_svg(self, request):
        """Export an existing drawing to SVG format with export settings specified.


        :param request PostDrawingSvgRequest object with parameters
        :return: file
        """
        HttpRequest = request.to_http_info(self.api_client.configuration)
        return self.__make_request(HttpRequest, 'POST', 'file')

    def post_drawing_svg_async(self, request):
        """Export an existing drawing to SVG format with export settings specified.


        :param request PostDrawingSvgRequest object with parameters
        :return: file
        """
        HttpRequest = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(HttpRequest, 'POST', 'file')

    def post_drawing_tiff(self, request):
        """Export an existing drawing into TIFF format with export settings specified.


        :param request PostDrawingTiffRequest object with parameters
        :return: file
        """
        HttpRequest = request.to_http_info(self.api_client.configuration)
        return self.__make_request(HttpRequest, 'POST', 'file')

    def post_drawing_tiff_async(self, request):
        """Export an existing drawing into TIFF format with export settings specified.


        :param request PostDrawingTiffRequest object with parameters
        :return: file
        """
        HttpRequest = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(HttpRequest, 'POST', 'file')

    def post_drawing_wmf(self, request):
        """Export an existing drawing to WMF format with export settings specified.


        :param request PostDrawingWmfRequest object with parameters
        :return: file
        """
        HttpRequest = request.to_http_info(self.api_client.configuration)
        return self.__make_request(HttpRequest, 'POST', 'file')

    def post_drawing_wmf_async(self, request):
        """Export an existing drawing to WMF format with export settings specified.


        :param request PostDrawingWmfRequest object with parameters
        :return: file
        """
        HttpRequest = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(HttpRequest, 'POST', 'file')

    def put_drawing_bmp(self, request):
        """Export drawing to BMP format. Drawing data is passed as zero-indexed multipart/form-data as well as export BMP options serialized as JSON. Order of drawing data and BMP options could vary.


        :param request PutDrawingBmpRequest object with parameters
        :return: file
        """
        HttpRequest = request.to_http_info(self.api_client.configuration)
        return self.__make_request(HttpRequest, 'PUT', 'file')

    def put_drawing_bmp_async(self, request):
        """Export drawing to BMP format. Drawing data is passed as zero-indexed multipart/form-data as well as export BMP options serialized as JSON. Order of drawing data and BMP options could vary.


        :param request PutDrawingBmpRequest object with parameters
        :return: file
        """
        HttpRequest = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(HttpRequest, 'PUT', 'file')

    def put_drawing_gif(self, request):
        """Export drawing to GIF format. Drawing data is passed as zero-indexed multipart/form-data as well as export GIF options serialized as JSON. Order of drawing data and GIF options could vary.


        :param request PutDrawingGifRequest object with parameters
        :return: file
        """
        HttpRequest = request.to_http_info(self.api_client.configuration)
        return self.__make_request(HttpRequest, 'PUT', 'file')

    def put_drawing_gif_async(self, request):
        """Export drawing to GIF format. Drawing data is passed as zero-indexed multipart/form-data as well as export GIF options serialized as JSON. Order of drawing data and GIF options could vary.


        :param request PutDrawingGifRequest object with parameters
        :return: file
        """
        HttpRequest = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(HttpRequest, 'PUT', 'file')

    def put_drawing_jpeg(self, request):
        """Export drawing to JPEG format. Drawing data is passed as zero-indexed multipart/form-data as well as export JPEG options serialized as JSON. Order of drawing data and JPEG options could vary.


        :param request PutDrawingJpegRequest object with parameters
        :return: file
        """
        HttpRequest = request.to_http_info(self.api_client.configuration)
        return self.__make_request(HttpRequest, 'PUT', 'file')

    def put_drawing_jpeg_async(self, request):
        """Export drawing to JPEG format. Drawing data is passed as zero-indexed multipart/form-data as well as export JPEG options serialized as JSON. Order of drawing data and JPEG options could vary.


        :param request PutDrawingJpegRequest object with parameters
        :return: file
        """
        HttpRequest = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(HttpRequest, 'PUT', 'file')

    def put_drawing_jpeg2000(self, request):
        """Export drawing to JPEG2000 format. Drawing data is passed as zero-indexed multipart/form-data as well as export JPEG2000 options serialized as JSON. Order of drawing data and JPEG2000 options could vary.


        :param request PutDrawingJpeg2000Request object with parameters
        :return: file
        """
        HttpRequest = request.to_http_info(self.api_client.configuration)
        return self.__make_request(HttpRequest, 'PUT', 'file')

    def put_drawing_jpeg2000_async(self, request):
        """Export drawing to JPEG2000 format. Drawing data is passed as zero-indexed multipart/form-data as well as export JPEG2000 options serialized as JSON. Order of drawing data and JPEG2000 options could vary.


        :param request PutDrawingJpeg2000Request object with parameters
        :return: file
        """
        HttpRequest = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(HttpRequest, 'PUT', 'file')

    def put_drawing_pdf(self, request):
        """Export drawing to PDF format. Drawing data is passed as zero-indexed multipart/form-data as well as export PDF options serialized as JSON. Order of drawing data and PDF options could vary.


        :param request PutDrawingPdfRequest object with parameters
        :return: file
        """
        HttpRequest = request.to_http_info(self.api_client.configuration)
        return self.__make_request(HttpRequest, 'PUT', 'file')

    def put_drawing_pdf_async(self, request):
        """Export drawing to PDF format. Drawing data is passed as zero-indexed multipart/form-data as well as export PDF options serialized as JSON. Order of drawing data and PDF options could vary.


        :param request PutDrawingPdfRequest object with parameters
        :return: file
        """
        HttpRequest = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(HttpRequest, 'PUT', 'file')

    def put_drawing_png(self, request):
        """Export drawing to PNG format. Drawing data is passed as zero-indexed multipart/form-data as well as export PNG options serialized as JSON. Order of drawing data and PNG options could vary.


        :param request PutDrawingPngRequest object with parameters
        :return: file
        """
        HttpRequest = request.to_http_info(self.api_client.configuration)
        return self.__make_request(HttpRequest, 'PUT', 'file')

    def put_drawing_png_async(self, request):
        """Export drawing to PNG format. Drawing data is passed as zero-indexed multipart/form-data as well as export PNG options serialized as JSON. Order of drawing data and PNG options could vary.


        :param request PutDrawingPngRequest object with parameters
        :return: file
        """
        HttpRequest = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(HttpRequest, 'PUT', 'file')

    def put_drawing_psd(self, request):
        """Export drawing to PSD format. Drawing data is passed as zero-indexed multipart/form-data as well as export PSD options serialized as JSON. Order of drawing data and PSD options could vary.


        :param request PutDrawingPsdRequest object with parameters
        :return: file
        """
        HttpRequest = request.to_http_info(self.api_client.configuration)
        return self.__make_request(HttpRequest, 'PUT', 'file')

    def put_drawing_psd_async(self, request):
        """Export drawing to PSD format. Drawing data is passed as zero-indexed multipart/form-data as well as export PSD options serialized as JSON. Order of drawing data and PSD options could vary.


        :param request PutDrawingPsdRequest object with parameters
        :return: file
        """
        HttpRequest = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(HttpRequest, 'PUT', 'file')

    def put_drawing_svg(self, request):
        """Export drawing to SVG format. Drawing data is passed as zero-indexed multipart/form-data as well as export SVG options serialized as JSON. Order of drawing data and SVG options could vary.


        :param request PutDrawingSvgRequest object with parameters
        :return: file
        """
        HttpRequest = request.to_http_info(self.api_client.configuration)
        return self.__make_request(HttpRequest, 'PUT', 'file')

    def put_drawing_svg_async(self, request):
        """Export drawing to SVG format. Drawing data is passed as zero-indexed multipart/form-data as well as export SVG options serialized as JSON. Order of drawing data and SVG options could vary.


        :param request PutDrawingSvgRequest object with parameters
        :return: file
        """
        HttpRequest = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(HttpRequest, 'PUT', 'file')

    def put_drawing_tiff(self, request):
        """Export drawing to TIFF format. Drawing data is passed as zero-indexed multipart/form-data as well as export TIFF options serialized as JSON. Order of drawing data and TIFF options could vary.


        :param request PutDrawingTiffRequest object with parameters
        :return: file
        """
        HttpRequest = request.to_http_info(self.api_client.configuration)
        return self.__make_request(HttpRequest, 'PUT', 'file')

    def put_drawing_tiff_async(self, request):
        """Export drawing to TIFF format. Drawing data is passed as zero-indexed multipart/form-data as well as export TIFF options serialized as JSON. Order of drawing data and TIFF options could vary.


        :param request PutDrawingTiffRequest object with parameters
        :return: file
        """
        HttpRequest = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(HttpRequest, 'PUT', 'file')

    def put_drawing_wmf(self, request):
        """Export drawing to WMF format. Drawing data is passed as zero-indexed multipart/form-data as well as export WMF options serialized as JSON. Order of drawing data and WMF options could vary.


        :param request PutDrawingWmfRequest object with parameters
        :return: file
        """
        HttpRequest = request.to_http_info(self.api_client.configuration)
        return self.__make_request(HttpRequest, 'PUT', 'file')

    def put_drawing_wmf_async(self, request):
        """Export drawing to WMF format. Drawing data is passed as zero-indexed multipart/form-data as well as export WMF options serialized as JSON. Order of drawing data and WMF options could vary.


        :param request PutDrawingWmfRequest object with parameters
        :return: file
        """
        HttpRequest = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(HttpRequest, 'PUT', 'file')

    def __make_request(self, HttpRequest, method, return_type):
        def call_api():
            return self.api_client.call_api(
                resource_path=HttpRequest.resource_path,
                method=method,
                path_params=HttpRequest.path_params,
                query_params=HttpRequest.query_params,
                header_params=HttpRequest.header_params,
                body=HttpRequest.body_params,
                post_params=HttpRequest.form_params,
                files=HttpRequest.files,
                response_type=return_type,
                auth_settings=HttpRequest.auth_settings,
                _return_http_data_only=HttpRequest.return_http_data_only,
                _preload_content=HttpRequest.preload_content,
                _request_timeout=HttpRequest.request_timeout,
                collection_formats=HttpRequest.collection_formats)

        try:
            return call_api()
        except ApiException as ex:
            if ex.code == 401:
                self.__request_token()
                return call_api()
            raise

    def __make_request_async(self, HttpRequest, method, return_type):
        def call_api_async():
            self.api_client.call_api_async(
                resource_path=HttpRequest.resource_path,
                method=method,
                path_params=HttpRequest.path_params,
                query_params=HttpRequest.query_params,
                header_params=HttpRequest.header_params,
                body=HttpRequest.body_params,
                post_params=HttpRequest.form_params,
                files=HttpRequest.files,
                response_type=return_type,
                auth_settings=HttpRequest.auth_settings,
                _return_http_data_only=HttpRequest.return_http_data_only,
                _preload_content=HttpRequest.preload_content,
                _request_timeout=HttpRequest.request_timeout,
                collection_formats=HttpRequest.collection_formats)

        try:
            return call_api_async()
        except ApiException as ex:
            if ex.code == 401:
                self.__request_token()
                return call_api_async()
            raise

    def __request_token(self):
        config = self.api_client.configuration
        request_url = "/connect/token"
        form_params = [('grant_type', 'client_credentials'), ('client_id', config.api_key['app_sid']),
                       ('client_secret', config.api_key['api_key'])]

        header_params = {'Accept': 'application/json', 'Content-Type': 'application/x-www-form-urlencoded'}

        api_version = self.api_client.configuration.api_version
        self.api_client.configuration.api_version = ''

        data = self.api_client.call_api(request_url, 'POST',
                                        {},
                                        [],
                                        header_params,
                                        post_params=form_params,
                                        response_type='object',
                                        files={}, _return_http_data_only=True)
        access_token = data['access_token'] if six.PY3 else data['access_token'].encode('utf8')
        self.api_client.configuration.access_token = access_token

        self.api_client.configuration.api_version = api_version

#  coding: utf


#  coding: utf-8
#  ----------------------------------------------------------------------------
#  <copyright company="Aspose" file="setup.py">
#    Copyright (c) 2019 Aspose Pty Ltd. All rights reserved.
#  </copyright>
#  <summary>
#    Permission is hereby granted, free of charge, to any person obtaining a
#   copy  of this software and associated documentation files (the "Software"),
#   to deal  in the Software without restriction, including without limitation
#   the rights  to use, copy, modify, merge, publish, distribute, sublicense,
#   and/or sell  copies of the Software, and to permit persons to whom the
#   Software is  furnished to do so, subject to the following conditions:
#
#   The above copyright notice and this permission notice shall be included in
#   all  copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#   FROM,  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#   DEALINGS IN THE SOFTWARE.
#  </summary>
#  ----------------------------------------------------------------------------

from setuptools import setup, find_packages

NAME = "aspose-cad-cloud"
VERSION = "19.11.0"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = [
    "urllib3>=1.22",
    "six>=1.11",
    "certifi>=2018.1",
    "python_dateutil>=2.8",
    "asposestoragecloud>=1.0.6"
]

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name=NAME,
    version=VERSION,
    description="Aspose.CAD Cloud Python SDK",
    author="Vitalii Kornyliuk",
    author_email="vitalii.kornyliuk@aspose.com",
    url="https://products.aspose.cloud/cad",
    licence="MIT",
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'Topic :: Multimedia :: Graphics',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.1',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
    ],
    keywords=[
        "Aspose",
        "CAD",
        "Cloud",
        "REST",
        "API",
        "SDK",
        "drawing",
        "DWG",
        "DXF",
        "DWF",
        "DWT",
        "STL",
        "IGS",
        "DGN",
        "OBJ",
        "CF2",
        "image",
        "bmp",
        "gif",
        "jpg",
        "jpeg",
        "jpeg2000",
        "jp2",
        "j2k",
        "png",
        "psd",
        "tiff",
        "tif",
        "wmf",
        "svg",
        "export",
        "conversion"],
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "test*"]),
    include_package_data=True,
    data_files=[("", ["LICENSE"])],
    long_description=long_description,
    long_description_content_type="text/markdown"
)



-8
#  ----------------------------------------------------------------------------
#  <copyright company="Aspose" file="CadRequest.py">
#    Copyright (c) 2018-2019 Aspose Pty Ltd. All rights reserved.
#  </copyright>
#  <summary>
#    Permission is hereby granted, free of charge, to any person obtaining a
#   copy  of this software and associated documentation files (the "Software"),
#   to deal  in the Software without restriction, including without limitation
#   the rights  to use, copy, modify, merge, publish, distribute, sublicense,
#   and/or sell  copies of the Software, and to permit persons to whom the
#   Software is  furnished to do so, subject to the following conditions:
#
#   The above copyright notice and this permission notice shall be included in
#   all  copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#   FROM,  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#   DEALINGS IN THE SOFTWARE.
#  </summary>
#  ----------------------------------------------------------------------------

from abc import ABCMeta, abstractmethod


class CadRequest(object):
    __metaclass__ = ABCMeta

    @abstractmethod
    def to_http_info(self, config):
        """
        Prepares initial info for HTTP request

        :param config: CAD API configuration.
        :type: asposecadcloud.Configuration
        :return: http_request configured http request
        :rtype: Configuration.models.requests.HttpRequest
        """
        pass

    @staticmethod
    def _select_header_accept(accepts):
        """Returns `Accept` based on an array of accepts provided.

        :param accepts: List of headers.
        :return: Accept (e.g. application/json).
        """
        if not accepts:
            return None

        accepts = [x.lower() for x in accepts]

        if 'application/json' in accepts:
            return 'application/json'

        return ', '.join(accepts)

    @staticmethod
    def _select_header_content_type(content_types):
        """Returns `Content-Type` based on an array of content_types provided.

        :param content_types: List of content-types.
        :return: Content-Type (e.g. application/json).
        """
        if not content_types:
            return 'application/json'

        content_types = [x.lower() for x in content_types]

        if 'application/json' in content_types or '*/*' in content_types:
            return 'application/json'

        return content_types[0]

    @staticmethod
    def _lowercase_first_letter(string):
        """
        Converts first letter of the string to lowercase

        :param string: initial string
        :return: initial string with first character in lowercase
        """
        if not string:
            return string

        return string[0].lower() + string[1:]
#  coding: utf